SlowmoCameraPreview class
A widget that renders a live camera preview provided by the native side of this plugin.
On iOS, the preview is backed by an AVCaptureVideoPreviewLayer that is
hosted inside an UIView. On any other platform the widget simply
displays an empty SizedBox.
The widget can be placed anywhere in the widget tree. Simply wrap it in an AspectRatio or FittedBox to constrain its dimensions.
Example:
SlowmoCameraPreview(
aspectRatio: 16 / 9,
)
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- SlowmoCameraPreview
Constructors
- SlowmoCameraPreview({Key? key, double? aspectRatio})
-
Constructs the preview.
const
Properties
- aspectRatio → double?
-
A helper to embed the preview in the desired aspect ratio.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< SlowmoCameraPreview> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited