aspectRatio property
A helper to embed the preview in the desired aspect ratio.
If null, the preview view will expand to fill its parent while keeping
its own intrinsic size.
Implementation
final double? aspectRatio;
A helper to embed the preview in the desired aspect ratio.
If null, the preview view will expand to fill its parent while keeping
its own intrinsic size.
final double? aspectRatio;